# adb-utils

对adb常用接口的二次开发

## Requirements
- 开发时使用的是python3.8, 大概python 3.6+都可以
- 项目里用到了[base_image](https://github.com/hakaboom/base_image) 因此需要额外安装opencv-python,后续会想办法优化掉


## Installation
pip3 install adb-utils


## 备注
由于工作内容,对于低版本android不打算做适配


## 函数
不打算写,看源码备注就行了
